==> gstreamermm-0.9.1.tar.bz2: gstreamermm-0.9.1/gstreamer/gstreamermm/gst_wrap_init.cc <==

#include <glib.h>

// Disable the 'const' function attribute of the get_type() functions.
// GCC would optimize them out because we don't use the return value.
#undef  G_GNUC_CONST
#define G_GNUC_CONST /* empty */

#include <gstreamermm/gst_wrap_init.h>
#include <glibmm/error.h>
#include <glibmm/object.h>

// #include the widget headers so that we can call the get_type() static methods:

#include "bin.h"
#include "bus.h"
#include "caps.h"
#include "clock.h"
#include "element.h"
#include "enums.h"
#include "error.h"
#include "event.h"
#include "format.h"
#include "iterator.h"
#include "message.h"
#include "pad.h"
#include "padtemplate.h"
#include "pipeline.h"
#include "query.h"
#include "structure.h"
#include "systemclock.h"
#include "xml.h"

extern "C"
{

//Declarations of the *_get_type() functions:

GType gst_event_get_type(void);
GType gst_message_get_type(void);
GType gst_query_get_type(void);

//Declarations of the *_error_quark() functions:

} // extern "C"


//Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:

namespace Gst {  class Event_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
namespace Gst {  class Message_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
namespace Gst {  class Query_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }

namespace Gst { 

void gst_wrap_init()
{

// Map gtypes to gstmm wrapper-creation functions:
  Gst::wrap_register(gst_event_get_type(), &Gst::Event_Class::wrap_new);
  Gst::wrap_register(gst_message_get_type(), &Gst::Message_Class::wrap_new);
  Gst::wrap_register(gst_query_get_type(), &Gst::Query_Class::wrap_new);

  // Register the gtkmm gtypes:
  Gst::Event::get_type();
  Gst::Message::get_type();
  Gst::Query::get_type();

} // gst_wrap_init()

} //Gst

==> gstreamermm-0.9.4.tar.bz2: gstreamermm-0.9.4/gstreamer/gstreamermm/gst_wrap_init.cc <==

#include <glib.h>

// Disable the 'const' function attribute of the get_type() functions.
// GCC would optimize them out because we don't use the return value.
#undef  G_GNUC_CONST
#define G_GNUC_CONST /* empty */

#include <gstreamermm/gst_wrap_init.h>
#include <glibmm/error.h>
#include <glibmm/object.h>

// #include the widget headers so that we can call the get_type() static methods:

#include "bin.h"
#include "buffer.h"
#include "bus.h"
#include "caps.h"
#include "childproxy.h"
#include "clock.h"
#include "element.h"
#include "elementfactory.h"
#include "enums.h"
#include "error.h"
#include "event.h"
#include "filter.h"
#include "format.h"
#include "index.h"
#include "indexfactory.h"
#include "iterator.h"
#include "message.h"
#include "pad.h"
#include "padtemplate.h"
#include "parse.h"
#include "pipeline.h"
#include "plugin.h"
#include "pluginfeature.h"
#include "query.h"
#include "structure.h"
#include "systemclock.h"
#include "task.h"
#include "urihandler.h"
#include "value.h"
#include "xml.h"

extern "C"
{

//Declarations of the *_get_type() functions:

GType gst_buffer_get_type(void);
GType gst_event_get_type(void);
GType gst_message_get_type(void);
GType gst_query_get_type(void);

//Declarations of the *_error_quark() functions:

} // extern "C"


//Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:

namespace Gst {  class Buffer_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
namespace Gst {  class Event_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
namespace Gst {  class Message_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }
namespace Gst {  class Query_Class { public: static Gst::MiniObject* wrap_new(GstMiniObject*); };  }

namespace Gst { 

void gst_wrap_init()
{

// Map gtypes to gstreamermm wrapper-creation functions:
  Gst::wrap_register(gst_buffer_get_type(), &Gst::Buffer_Class::wrap_new);
  Gst::wrap_register(gst_event_get_type(), &Gst::Event_Class::wrap_new);
  Gst::wrap_register(gst_message_get_type(), &Gst::Message_Class::wrap_new);
  Gst::wrap_register(gst_query_get_type(), &Gst::Query_Class::wrap_new);

  // Register the gtkmm gtypes:
  Gst::Buffer::get_type();
  Gst::Event::get_type();
  Gst::Message::get_type();
  Gst::Query::get_type();

} // gst_wrap_init()

} //Gst
